package com.cultural.heritage.model.dto.advanceOrder;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;

@Data
@Schema(description = "预约订单添加请求体", requiredProperties = {"type", "clothesType", "deposit", "contactsSnapshot",
        "specificDate", "timeSlot", "isIndoors", "isMakeup", "isPhotography"})
public class AdvanceOrderAddRequest implements Serializable {


    /**
     * 预约类别
     */
    @Schema(description = "预约类别", example = "整套约拍")
    private String type;


    /**
     * 服装类别名称
     */
    @Schema(description = "服装类别名称", example = "时尚精选")
    private String clothesType;


    /**
     * 定金
     */
    @Schema(description = "定金", example = "100.00")
    private BigDecimal deposit;


    /**
     * 联系人id
     */
    @Schema(description = "联系人id(id > 0)", example = "3")
    private Long contactsId;


    /**
     * 预约具体日期
     */
    @Schema(description = "预约具体日期", example = "2024-11-18")
    private String specificDate;


    /**
     * 预约时间段
     */
    @Schema(description = "预约时间段", example = "8:00-10:00")
    private String timeSlot;


    /**
     * 是否是室内
     */
    @Schema(description = "是否是室内", example = "1")
    private Integer isIndoors;


    /**
     * 是否选择妆发服务
     */
    @Schema(description = "是否选择妆发服务", example = "1")
    private Integer isMakeup;


    /**
     * 是否选择摄影服务
     */
    @Schema(description = "是否选择摄影服务", example = "1")
    private Integer isPhotography;


    /**
     * 订单状态
     */
    @Schema(description = "订单状态", example = "待付款")
    private String orderStatus;



    @Serial
    private static final long serialVersionUID = 1L;
}
