package com.cultural.heritage.service.book.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.constant.CommonConstant;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.mapper.ClothesInfoMapper;
import com.cultural.heritage.model.dto.clothesinfo.ClothesInfoQueryRequest;
import com.cultural.heritage.model.entity.ClothesInfo;
import com.cultural.heritage.service.book.ClothesInfoService;
import com.cultural.heritage.utils.SqlUtils;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;

@Service
public class ClothesInfoServiceImpl extends ServiceImpl<ClothesInfoMapper, ClothesInfo> implements ClothesInfoService {


    /**
     * 校验
     */
    @Override
    public void validClothesInfo(ClothesInfo clothesInfo, boolean update) {
        Long id = clothesInfo.getId();
        String name = clothesInfo.getName();
        String image = clothesInfo.getImage();
        String effectImg = clothesInfo.getEffectImg();
        String intro = clothesInfo.getIntro();
        BigDecimal price = clothesInfo.getPrice();
        String clothesType = clothesInfo.getClothesType();
        if (update) {
            if (id == null) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR);
            }
        }
        if (StringUtils.isAnyBlank(name, image, effectImg, intro, clothesType)) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "参数不全");
        }
        if (ObjectUtils.isEmpty(price) || price.compareTo(BigDecimal.ZERO) < 0) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "价格参数错误");
        }
    }


    /**
     * 获取查询条件
     */
    @Override
    public QueryWrapper<ClothesInfo> getQueryWrapper(ClothesInfoQueryRequest clothesInfoQueryRequest) {
        Long id = clothesInfoQueryRequest.getId();
        String name = clothesInfoQueryRequest.getName();
        BigDecimal minPrice = clothesInfoQueryRequest.getMinPrice();
        BigDecimal maxPrice = clothesInfoQueryRequest.getMaxPrice();
        String clothesType = clothesInfoQueryRequest.getClothesType();
        String sortField = clothesInfoQueryRequest.getSortField();
        String sortOrder = clothesInfoQueryRequest.getSortOrder();

        QueryWrapper<ClothesInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(id != null, "id", id);
        queryWrapper.like(StringUtils.isNotBlank(name), "name", name);
        queryWrapper.eq(StringUtils.isNotBlank(clothesType), "clothesType", clothesType);
        queryWrapper.ge(ObjectUtils.isNotEmpty(minPrice), "price", minPrice);
        queryWrapper.le(ObjectUtils.isNotEmpty(maxPrice), "price", maxPrice);
        queryWrapper.orderBy(SqlUtils.validSortField(sortField), sortOrder.equals(CommonConstant.SORT_ORDER_ASC),
                sortField);
        return queryWrapper;
    }
}
